==> netwib-5.30.0-src.tgz: netwib-5.30.0-src/src/netwib/dat/debug.c <==
/*
                                  NETWIB
                             Network library
                Copyright(c) 1999-2005 Laurent Constantin
                                  -----

  Main server    : http://www.laurentconstantin.com/
  Backup servers : http://go.to/laurentconstantin/
                   http://laurentconstantin.est-la.com/
                   http://laurentconstantin.free.fr/
                   http://membres.lycos.fr/lauconstantin/
  [my current email address is on the web servers]

                                  -----
  This file is part of Netwib.

  Netwib is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  version 2 as published by the Free Software Foundation.

  Netwib is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  General Public License for more details (http://www.gnu.org/).

------------------------------------------------------------------------
*/

#include <netwib/inc/maininc.h>


/*-------------------------------------------------------------*/
#if NETWIB_DEBUG==1
 #include "debug/str.c"
 #include "debug/str2.c"
#endif


/*-------------------------------------------------------------*/
#if NETWIB_DEBUG_MEMPROTECT_NEEDED==1
 #include "debug/memprotect.c"
#endif

/*-------------------------------------------------------------*/
#if NETWIB_DEBUG_MEMCORRUPT_NEEDED==1
 #include "debug/memcorrupt.c"
#endif

/*-------------------------------------------------------------*/
static netwib_err netwib_unused_dat_debug(void)
{
  netwib_unused_dat_debug();
  return(NETWIB_ERR_OK);
}

==> netwib-5.35.0-src.tgz: netwib-5.35.0-src/src/netwib/dat/debug.c <==
/*
                                  NETWIB
                             Network library
                Copyright(c) 1999-2006 Laurent Constantin
                                  -----

  Main server    : http://www.laurentconstantin.com/
  Backup servers : http://go.to/laurentconstantin/
                   http://laurentconstantin.est-la.com/
                   http://laurentconstantin.free.fr/
                   http://membres.lycos.fr/lauconstantin/
  [my current email address is on the web servers]

                                  -----
  This file is part of Netwib.

  Netwib is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  version 2 as published by the Free Software Foundation.

  Netwib is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  General Public License for more details (http://www.gnu.org/).

------------------------------------------------------------------------
*/

#include <netwib/inc/maininc.h>


/*-------------------------------------------------------------*/
#if NETWIB_DEBUG==1
 #include "debug/string.c"
 #include "debug/string2.c"
#endif


/*-------------------------------------------------------------*/
#if NETWIB_DEBUG_MEMPROTECT_NEEDED==1
 #include "debug/memprotect.c"
#endif

/*-------------------------------------------------------------*/
#if NETWIB_DEBUG_MEMCORRUPT_NEEDED==1
 #include "debug/memcorrupt.c"
#endif

/*-------------------------------------------------------------*/
static netwib_err netwib_unused_dat_debug(void)
{
  netwib_unused_dat_debug();
  return(NETWIB_ERR_OK);
}
